@@ -14,10 +14,22 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo.config import cfg
+import logging
+import warnings
+
+from oslo_config import cfg
+from oslo_log import log
+
+import caso
+
+logging.captureWarnings(True)
+warnings.simplefilter("default", DeprecationWarning)
+
+log.register_options(cfg.CONF)
 
 
 def parse_args(argv, default_config_files=None):
     cfg.CONF(argv[1:],
              project='caso',
+             version=caso.__version__,
              default_config_files=default_config_files)
