@@ -14,7 +14,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from caso import log
+from oslo_log import log
+import six
+
 import caso.messenger
 
 LOG = log.getLogger(__name__)
@@ -24,5 +26,5 @@ class NoopMessenger(caso.messenger.BaseMessenger):
     """Noop messenger that does nothing."""
     def push(self, records):
         """Push records to nowhere."""
-        for uuid, _ in records.iteritems():
+        for uuid, _ in six.iteritems(records):
             LOG.info("nooping %s" % uuid)
